@@ -11,14 +11,20 @@ sys.path.append(
     os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)),
 )  # isort: skip # noqa # pylint: disable=wrong-import-position
 
-from persontitles import (  # type: ignore # isort:skip # noqa # pylint: disable=unused-import, wrong-import-position
+from src.persontitles.degrees import (  # type: ignore # isort:skip # noqa # pylint: disable=unused-import, wrong-import-position
     academic_german,
     academic_german_wiki,
     academic_german_drtitel,
     academic_uk,
     academic_us,
     academic_degrees,
+)  # pylint: disable=unused-import  # noqa
+
+from src.persontitles.titles import (  # type: ignore # isort:skip # noqa # pylint: disable=unused-import, wrong-import-position
     peertitles,
+)  # pylint: disable=unused-import  # noqa
+
+from src.persontitles.jobs import (  # type: ignore # isort:skip # noqa # pylint: disable=unused-import, wrong-import-position
     job_titles,
     gov_jobs,
 )  # pylint: disable=unused-import  # noqa
